@@ -24,6 +24,7 @@ class PanZoomPlugin(BasePlugin):
         ("exclude", config_options.Type(list, default=[])),
         ("include_selectors", config_options.Type(list, default=[])),
         ("exclude_selectors", config_options.Type(list, default=[])),
+        ("hint_location", config_options.Type(str, default="bottom")),
     )
 
     def on_config(self, config, **kwargs):
@@ -53,8 +54,6 @@ class PanZoomPlugin(BasePlugin):
         if exclude(page.file.src_path,excluded_pages):
             return
 
-        #print(page.content)
-
         html_page = HTMLPage(output,self.config,page, config)
 
         html_page.add_panzoom()
@@ -66,7 +65,6 @@ class PanZoomPlugin(BasePlugin):
 
         output_base_path = os.path.join(config["site_dir"], "assets")
         css_path = os.path.join(output_base_path, "stylesheets")
-        print(css_path)
         utils.copy_file(
             os.path.join(base_path, "custom", "panzoom.css"),
             os.path.join(css_path, "panzoom.css"),
